body{
    background-color: #eee;
    color: #2e2e2e;
    margin: 20px;
    padding: 0;
    font-size: 14px;
    line-height: 28px;
    font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
}

.wrapper{
    max-width: 1220px;
    margin: 0 auto;
}
.main{
    width:75%;
    float:left;
    background-color:#fff;
    border:1px solid #ccc;
    border-radius: 10px;
    margin-top:20px;
    padding:10px;
}
.secondary{
    width:25%;
    float:left;
    background-color: #eee;
}

/**** main *****/
.main article{
    padding:20px;
}
.posttime{
    font-style: italic;
}
img{
  max-width: 100%;
}

.clear{
clear: both;
}

figcaption{
  color:#8E8E8E;
}

footer{
padding-top: 20px;
text-align: center;
}
